@@ -52,7 +52,7 @@ use strict;
 
 package RT::Extension::ExternalStorage;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 use Digest::SHA qw//;
 
@@ -79,7 +79,8 @@ textual content and images) to outside of the database.  This may either
 be on local disk, or to a cloud storage solution.  This decreases the
 size of RT's database, in turn decreasing the burden of backing up RT's
 database, at the cost of adding additional locations which must be
-configured or backed up.
+configured or backed up.  Attachment storage paths are calculated based
+on file contents; this provides de-duplication.
 
 The files are initially stored in the database when RT receives them;
 this guarantees that the user does not need to wait for the file to be
@@ -154,6 +155,12 @@ documentation in each for necessary configuration details:
 
 =back
 
+=head1 CAVEATS
+
+This extension is not currently compatibile with RT's C<shredder> tool;
+attachments which are shredded will not be removed from external
+storage.
+
 =cut
 
 our $BACKEND;
